==> myfaces-core-assembly-2.2.14-src.zip: myfaces-core-module-2.2.14/api/src/main/java/javax/faces/view/facelets/TagHandlerDelegateFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package javax.faces.view.facelets;

import javax.faces.FacesWrapper;

/**
 * @since 2.0
 */
public abstract class TagHandlerDelegateFactory implements FacesWrapper<TagHandlerDelegateFactory>
{
    public abstract TagHandlerDelegate createBehaviorHandlerDelegate(BehaviorHandler owner);
    
    public abstract TagHandlerDelegate createComponentHandlerDelegate(ComponentHandler owner);
    
    public abstract TagHandlerDelegate createConverterHandlerDelegate(ConverterHandler owner);
    
    public abstract TagHandlerDelegate createValidatorHandlerDelegate(ValidatorHandler owner);
    
    /**
     * @since 2.2
     * @return 
     */
    public TagHandlerDelegateFactory getWrapped()
    {
        return null;
    }
}

==> myfaces-core-assembly-2.3.9-src.zip: myfaces-core-module-2.3.9/api/src/main/java/javax/faces/view/facelets/TagHandlerDelegateFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package javax.faces.view.facelets;

import javax.faces.FacesWrapper;

/**
 * @since 2.0
 */
public abstract class TagHandlerDelegateFactory implements FacesWrapper<TagHandlerDelegateFactory>
{
    private TagHandlerDelegateFactory delegate;

    @Deprecated
    public TagHandlerDelegateFactory()
    {
    }

    public TagHandlerDelegateFactory(TagHandlerDelegateFactory delegate)
    {
        this.delegate = delegate;
    }
    
    public abstract TagHandlerDelegate createBehaviorHandlerDelegate(BehaviorHandler owner);
    
    public abstract TagHandlerDelegate createComponentHandlerDelegate(ComponentHandler owner);
    
    public abstract TagHandlerDelegate createConverterHandlerDelegate(ConverterHandler owner);
    
    public abstract TagHandlerDelegate createValidatorHandlerDelegate(ValidatorHandler owner);
    
    /**
     * @since 2.2
     * @return 
     */
    public TagHandlerDelegateFactory getWrapped()
    {
        return delegate;
    }
}
